import { Chain, ChainToPlatform, Network, Platform, PlatformToChains } from "@wormhole-foundation/sdk-base";
import { AttestationId, AutomaticTokenBridge, ChainContext, Signer, TokenBridge, TokenId, TokenTransferDetails, TransactionId, TxHash, WormholeMessageId } from "@wormhole-foundation/sdk-definitions";
import { Wormhole } from "../wormhole";
import { TransferQuote, TransferReceipt, TransferState, WormholeTransfer } from "../wormholeTransfer";
type TransferProtocol = "TokenBridge" | "AutomaticTokenBridge";
type TransferVAA = TokenBridge.TransferVAA | AutomaticTokenBridge.VAA;
export declare class TokenTransfer<N extends Network = Network> implements WormholeTransfer<TransferProtocol> {
    private readonly wh;
    private _state;
    transfer: TokenTransferDetails;
    txids: TransactionId[];
    vaas?: {
        id: WormholeMessageId;
        vaa?: TransferVAA;
    }[];
    private constructor();
    getTransferState(): TransferState;
    static from<N extends Network>(wh: Wormhole<N>, from: TokenTransferDetails): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: WormholeMessageId, timeout?: number): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: TransactionId, timeout?: number): Promise<TokenTransfer<N>>;
    private static fromIdentifier;
    private static fromTransaction;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    fetchAttestation(timeout?: number): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
    static track<N extends Network>(wh: Wormhole<N>, receipt: TransferReceipt<TransferProtocol>, timeout?: number, _fromChain?: ChainContext<N, ChainToPlatform<typeof receipt.from>, typeof receipt.from>, _toChain?: ChainContext<N, ChainToPlatform<typeof receipt.to>, typeof receipt.to>): AsyncGenerator<TransferState.SourceFinalized | TransferState.Attested | TransferState.DestinationFinalized, TransferReceipt<TransferProtocol>, unknown>;
    static transfer<N extends Network>(fromChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails, signer: Signer<N, Chain>): Promise<TransactionId[]>;
    static redeem<N extends Network>(toChain: ChainContext<N, Platform, Chain>, vaa: TokenBridge.TransferVAA | AutomaticTokenBridge.VAA, signer: Signer<N, Chain>): Promise<TransactionId[]>;
    static isTransferComplete<N extends Network, P extends Platform, C extends PlatformToChains<P>>(toChain: ChainContext<N, P, C>, vaa: TransferVAA): Promise<boolean>;
    static getTransferMessage<N extends Network, P extends Platform, C extends PlatformToChains<P>>(chain: ChainContext<N, P, C>, txid: TxHash, timeout?: number): Promise<WormholeMessageId>;
    static getTransferVaa<N extends Network>(wh: Wormhole<N>, key: WormholeMessageId | TxHash, timeout?: number): Promise<TransferVAA>;
    static lookupDestinationToken<N extends Network, SC extends Chain, DC extends Chain>(srcChain: ChainContext<N, ChainToPlatform<SC>, SC>, dstChain: ChainContext<N, ChainToPlatform<DC>, DC>, token: TokenId<SC> | "native"): Promise<TokenId<DC>>;
    static validateTransferDetails<N extends Network>(wh: Wormhole<N>, transfer: TokenTransferDetails): Promise<void>;
    static quoteTransfer<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails): Promise<TransferQuote>;
    static destinationOverrides<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails): Promise<TokenTransferDetails>;
    static getReceipt<N extends Network>(xfer: TokenTransfer<N>): TransferReceipt<"TokenBridge" | "AutomaticTokenBridge", typeof xfer.transfer.from.chain, typeof xfer.transfer.to.chain>;
}
export {};
//# sourceMappingURL=tokenTransfer.d.ts.map